"""
QInfPy: A Python package for Quantum Information
================================================
"""

#Run basic/__init__.py
from .basic import *

#That basic.__init__.py file is written in such a way that running it here 
#will import all functions in the 'basic' sub-package to the namespace of
#this top-level package

